# YOLO Inference Library

This library provides an interface for YOLO-based object detection.

## Installation

```bash
pip install # YOLO Inference Library

This library provides an interface for YOLO-based object detection.

## Installation

```bash
pip install git+https://bitbucket.org/godigit/cv_motor_4wclaim_gpuservices.git@feature/AIML-12807-lib_test#egg=yolo-inference&subdirectory=v5_lib